==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Account_Profile.pm <==
package WebGUI::i18n::English::Account_Profile;
use strict;

our $I18N = {

    'title' => {
        message     => q{Profile},
        lastUpdated => 1228764827,
        context     => q{Tab label for Profile Account plugin},
    },

    'profile style template label' => {
        message     => q|Style Template|,
        lastUpdated => 1119068809
	},

    'profile style template hoverHelp' => {
        message     => q|Select a style template from the list to enclose the profile in.|,
        lastUpdated => 1119068809
	},

    'profile layout template label' => {
        message     => q|Edit Layout Template|,
        lastUpdated => 1119068809
	},
    
    'profile layout template hoverHelp' => {
        message     => q{Choose a layout from the list to display the various account plugins that are usable by the current user as well as the contents of the plugin currently chosen.},
        lastUpdated => 1228773692
    },

    'profile view template label' => {
        message     => q|View Template|,
        lastUpdated => 1119068809
    },

    'profile view template hoverHelp' => {
        message     => q|Choose the main template for viewing a profile.|,
        lastUpdated => 1119068809
    },

    'profile edit template label' => {
        message     => q|Edit Template|,
        lastUpdated => 1119068809
    },

    'profile edit template hoverHelp' => {
        message     => q|Choose the main template for editing a profile|,
        lastUpdated => 1119068809
    },

    'profile edit layout template label' => {
        message     => q{Display Layout Template},
        lastUpdated => 1119068809
    },

    'profile edit layout template hoverHelp' => {
        message     => q{Choose a layout from the list to display the user's profile for editing.},
        lastUpdated => 1119068809
    },

    'profile error template label' => {
        message     => q|Error Template|,
        lastUpdated => 1119068809
    },

    'profile error template hoverHelp' => {
        message     => q|Choose the template to use for displaying profile errors to the user|,
        lastUpdated => 1119068809
    },


    'visitor profile restricted' => {
        message => q|The visitor profile is restricted|,
		lastUpdated => 1068703399
    },

    'edit my profile' => {
        message => q|edit my profile|,
		lastUpdated => 1068703399    
    },
    
    'view my profile' => {
        message => q|view my profile|,
		lastUpdated => 1068703399    
    },

    'profile as others label' => {
        message     => q{view my profile as others see it},
        lastUpdated => 1119068809
    },

    'member since' => {
        message     => q{Member Since },
        lastUpdated => 1119068809
    },

    'send private message label' => {
        message     => q{Send Private Message},
        lastUpdated => 1119068809
    },

    'send friend request label' => {
        message     => q{Send Friend Request},
        lastUpdated => 1119068809
    },

    'back label' => {
        message     => q{back to site},
        lastUpdated => 1119068809
    },

    'profile not public error' => {
		message => q|This user's profile is not public.|,
		lastUpdated => 1043881275
	},

    'friends only' => {
		message => q|Your profile is viewable to Friends|,
		lastUpdated => 1043881275
	},

    'private profile' => {
		message => q|Your profile is Private|,
		lastUpdated => 1043881275
	},

    'public profile' => {
		message => q|Your profile is Public|,
		lastUpdated => 1043881275
	},

    'private label' => {
    	message => q|Private|,
		lastUpdated => 1043881275
    },
    
    'public label' => {
    	message => q|Public|,
		lastUpdated => 1043881275
    },

    'friends only label' => {
    	message => q|Friends Only|,
		lastUpdated => 1043881275
    },

    'error label' => {
        message     => q{Error},
        lastUpdated => 1225724810,
    },
    
    'back to profile label' => {
        message     => q{back to profile},
        lastUpdated => 1225724810,
    },

    'save changes' => {
        message     => q{save changes},
        lastUpdated => 1225724810,
    },

    'set by admin' => {
        message     => q{site administrator has set this field to not be visible },
        lastUpdated => 1225724810,
    },

    'required field' => {
        message     => q{required },
        lastUpdated => 1225724810,
    },
};

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Account_Profile.pm <==
package WebGUI::i18n::English::Account_Profile;
use strict;

our $I18N = {

    'title' => {
        message     => q{Profile},
        lastUpdated => 1228764827,
        context     => q{Tab label for Profile Account plugin},
    },

    'profile style template label' => {
        message     => q|Style Template|,
        lastUpdated => 1119068809
	},

    'profile style template hoverHelp' => {
        message     => q|Select a style template from the list to enclose the profile in.|,
        lastUpdated => 1119068809
	},

    'profile layout template label' => {
        message     => q|Edit Layout Template|,
        lastUpdated => 1119068809
	},
    
    'profile layout template hoverHelp' => {
        message     => q{Choose a layout from the list to display the various account plugins that are usable by the current user as well as the contents of the plugin currently chosen.},
        lastUpdated => 1228773692
    },

    'profile view template label' => {
        message     => q|View Template|,
        lastUpdated => 1119068809
    },

    'profile view template hoverHelp' => {
        message     => q|Choose the main template for viewing a profile.|,
        lastUpdated => 1119068809
    },

    'profile edit template label' => {
        message     => q|Edit Template|,
        lastUpdated => 1119068809
    },

    'profile edit template hoverHelp' => {
        message     => q|Choose the main template for editing a profile|,
        lastUpdated => 1119068809
    },

    'profile edit layout template label' => {
        message     => q{Display Layout Template},
        lastUpdated => 1119068809
    },

    'profile edit layout template hoverHelp' => {
        message     => q{Choose a layout from the list to display the user's profile for editing.},
        lastUpdated => 1119068809
    },

    'profile error template label' => {
        message     => q|Error Template|,
        lastUpdated => 1119068809
    },

    'profile error template hoverHelp' => {
        message     => q|Choose the template to use for displaying profile errors to the user|,
        lastUpdated => 1119068809
    },


    'visitor profile restricted' => {
        message => q|The visitor profile is restricted|,
		lastUpdated => 1068703399
    },

    'edit my profile' => {
        message => q|edit my profile|,
		lastUpdated => 1068703399    
    },
    
    'view my profile' => {
        message => q|view my profile|,
		lastUpdated => 1068703399    
    },

    'profile as others label' => {
        message     => q{view my profile as others see it},
        lastUpdated => 1119068809
    },

    'member since' => {
        message     => q{Member Since },
        lastUpdated => 1119068809
    },

    'send private message label' => {
        message     => q{Send Private Message},
        lastUpdated => 1119068809
    },

    'send friend request label' => {
        message     => q{Send Friend Request},
        lastUpdated => 1119068809
    },

    'back label' => {
        message     => q{back to site},
        lastUpdated => 1119068809
    },

    'profile not public error' => {
		message => q|This user's profile is not public.|,
		lastUpdated => 1043881275
	},

    'friends only' => {
		message => q|Your profile is viewable to Friends|,
		lastUpdated => 1043881275
	},

    'private profile' => {
		message => q|Your profile is Private|,
		lastUpdated => 1043881275
	},

    'public profile' => {
		message => q|Your profile is Public|,
		lastUpdated => 1043881275
	},

    'private label' => {
    	message => q|Private|,
		lastUpdated => 1043881275
    },
    
    'public label' => {
    	message => q|Public|,
		lastUpdated => 1043881275
    },

    'friends only label' => {
    	message => q|Friends Only|,
		lastUpdated => 1043881275
    },

    'error label' => {
        message     => q{Error},
        lastUpdated => 1225724810,
    },
    
    'back to profile label' => {
        message     => q{back to profile},
        lastUpdated => 1225724810,
    },

    'save changes' => {
        message     => q{save changes},
        lastUpdated => 1225724810,
    },

    'set by admin' => {
        message     => q{site administrator has set this field to not be visible },
        lastUpdated => 1225724810,
    },

    'required field' => {
        message     => q{required },
        lastUpdated => 1225724810,
    },
    'assetManagerSortDirection label' => {
        message     => 'Asset Manager Sort Direction',
        lastUpdated => 1307982524,
    },
    'assetManagerSortColumn label' => {
        message     => 'Asset Manager Sort Column',
        lastUpdated => 1307982524,
    },
    'ascending' => {
        message     => 'Ascending',
        lastUpdated => 1307982524,
        context     => 'Ascending sort order (lowest to highest)',
    },
    'descending' => {
        message     => 'Descending',
        lastUpdated => 1307982524,
        context     => 'Descending sort order (highest to lowest)',
    },
};

1;
